<script setup>

import AdminAuthenticatedLayout from '@/Layouts/AdminAuthenticatedLayout.vue';
import { ref, onMounted, computed } from 'vue';
import { Head, usePage, useForm } from '@inertiajs/vue3';
import NavLink from '@/Components/NavLink.vue';

const page = usePage();
const user = page.props.user;
const addresses = computed(() => page.props.addresses || []);
console.log(page);
const loading = computed(() => page.props.loading || false);

const isMobile = ref(window.innerWidth <= 768);
const flashMessage = ref('');

defineProps({
    status: {
        type: String,
    },
    errorMsg: {
        type: String,
    },
});

const form = useForm({
    id: '',
});

const sortDirections = ref({});
const sortBy = (key) => {
  // If the key has not been sorted before, default to ascending
  if (!sortDirections.value[key]) {
    sortDirections.value[key] = 'asc';
  } else {
    // If it was ascending before, now make it descending, and vice versa
    sortDirections.value[key] = sortDirections.value[key] === 'asc' ? 'desc' : 'asc';
  }

  const direction = sortDirections.value[key];
  addresses.value.sort((a, b) => {
    if (a[key] < b[key]) {
      return direction === 'asc' ? -1 : 1;
    }
    if (a[key] > b[key]) {
      return direction === 'asc' ? 1 : -1;
    }
    return 0;
  });
};

const sortedAddresses = computed(() => addresses.value);

const editUser = (user) => {
  window.location.href = `/admin/user/edit/${user.id}`;
  window.location.href = `admin/user/${user.id}/address/edit/1`;
};

const deleteUser = (user) => {
  const userID = user.id

  if (confirm('Are you sure you want to delete this user?')) {
    // admin.users.delete
    form.post(route('admin.users.delete',{id: userID}), {
        onSuccess: () => {
            // Update your success message or perform other actions here
            flashMessage.value = "User deleted successfully!";
        },
        onError: (error) => {
            // Handle error case here, if needed
            console.error(error);
        }
    });
  }
};

const handleResize = () => {
    isMobile.value = window.innerWidth <= 768; // Adjust the threshold as needed
}

onMounted(() => {
    window.addEventListener('resize', handleResize);
    handleResize();
});
</script>

<template>
    <Head title="Admin Dashboard" />

    <AdminAuthenticatedLayout>
        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">User Addresses
                <NavLink :href="route('admin.user.address.add', { id: user.id })" :active="route().current('admin.user.address.add')">
                    + Add Address
                </NavLink>
            </h2>
        </template>

        <div v-if="status" class="mb-4 font-medium text-sm text-green-600">
            {{ status }}
        </div>

        {{ page.props.add }}

        <div v-if="errorMsg" class="mb-4 font-medium text-sm text-red-600">
            {{ errorMsg }}
        </div>

        <div class="py-12">

            <div v-if="flashMessage" class="max-w-7xl mx-auto sm:px-6 lg:px-8 font-bold text-red-600">
                <div class="form-row mb-6">
                    <div class="col-md-6">
                        <h4>{{ flashMessage }}</h4>
                    </div>
                </div>
            </div>

            <div class="max-w-7xl mx-auto sm:px-6 lg:px-8">
                <div v-if="loading">Loading...</div>
                <table v-else-if="addresses && addresses.length" class="table table-striped">
                    <thead>
                        <tr>
                        <th @click="sortBy('name')" class="cursor-pointer">Name</th>
                        <th @click="sortBy('address1')" class="cursor-pointer">Address</th>
                        <th @click="sortBy('city')" class="cursor-pointer">City</th>
                        <th @click="sortBy('state')" class="cursor-pointer">State</th>
                        <th @click="sortBy('country')" class="cursor-pointer">Country</th>
                        <th @click="sortBy('zip')" class="cursor-pointer">Zip</th>
                        <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr v-for="address in sortedAddresses" :key="address.id">
                        <td>{{ address.name }}</td>
                        <td>{{ address.address1 }} {{ address.address2 }}</td>
                        <td>{{ address.city }}</td>
                        <td>{{ address.state }}</td>
                        <td>{{ address.country }}</td>
                        <td>{{ address.zip }}</td>
                        <td>
                            <NavLink :href="route('admin.user.address.edit', { id: user.id, aid: address.id })" :active="route().current('admin.user.address.edit')">
                                <button class="px-3"><i class="fa fa-pen text-green-600"></i> </button>
                            </NavLink>
                            <button class="mx-3" @click="deleteUser(address)"> <i class="fa fa-trash text-red-600"></i></button>
                        </td>
                        </tr>
                    </tbody>
                </table>
                <p v-else>No address found.</p>
            </div>
        </div>
    </AdminAuthenticatedLayout>
</template>
